@@ -1,4 +1,4 @@
 if (typeof(window.console) == "undefined") { console = {}; console.log = console.warn = console.error = function(a) {}; }
 
-$(function () {
+document.addEventListener("DOMContentLoaded", function () {
 });
